@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler superclass
-our $VERSION = '2.20200930.2'; # VERSION
+our $VERSION = '2.20201113.2'; # VERSION
 use Mail::Milter::Authentication::Exception;
 use Mail::Milter::Authentication::Resolver;
 use Date::Format qw{ time2str };
@@ -1466,6 +1466,15 @@ sub delete_dequeue($self,$id) {
 }
 
 
+sub error_dequeue($self,$id) {
+    my $dir = $self->_dequeue_dir;
+    my $filepath = join('/',$dir,$id);
+    return if ! -e $filepath;
+    return if ! -f $filepath;
+    rename $filepath, $filepath . '.err';
+}
+
+
 sub is_local_ip_address {
     my ($self) = @_;
     return 0 if ! $self->is_handler_loaded('LocalIP');
@@ -1762,6 +1771,16 @@ sub get_my_hostname {
 }
 
 
+sub get_my_authserv_id {
+    my ($self) = @_;
+    my $config = $self->config();
+    if ( exists( $config->{'authserv_id'} ) && $config->{'authserv_id'} ) {
+	return $config->{'authserv_id'};
+    }
+    return $self->get_my_hostname();
+}
+
+
 
 # Logging
 
@@ -1923,7 +1942,7 @@ sub add_headers {
 
     my $config = $self->config();
 
-    my $header = $self->get_my_hostname();
+    my $header = $self->get_my_authserv_id();
     my $top_handler = $self->get_top_handler();
 
     my @auth_headers;
@@ -1954,7 +1973,7 @@ sub add_headers {
             $header .= join( ";\n    ", map { $self->_stringify_header( $_ ) } @auth_headers );
         }
         else {
-            $header_obj->set_value( Mail::AuthenticationResults::Header::AuthServID->new()->safe_set_value( $self->get_my_hostname() ) );
+            $header_obj->set_value( Mail::AuthenticationResults::Header::AuthServID->new()->safe_set_value( $self->get_my_authserv_id() ) );
             $header_obj->set_eol( "\n" );
             if ( exists( $config->{'header_indent_style'} ) ) {
                 $header_obj->set_indent_style( $config->{'header_indent_style'} );
@@ -2135,7 +2154,7 @@ Mail::Milter::Authentication::Handler - Handler superclass
 
 =head1 VERSION
 
-version 2.20200930.2
+version 2.20201113.2
 
 =head1 DESCRIPTION
 
@@ -2518,6 +2537,10 @@ Return a previously queued item
 
 Delete a previously queued item
 
+=head2 I<error_dequeue($id)>
+
+Mark a previously queued item as errored
+
 =head2 I<is_local_ip_address()>
 
 Is the current connection from a local ip address?
@@ -2594,6 +2617,10 @@ Extract all email address from a string as an arrayref.
 
 Return the effective hostname of the MTA.
 
+=head2 I<get_my_authserv_id()>
+
+Return the effective authserv-id. Defaults to hostname if not explicitly set.
+
 =head1 LOGGING METHODS
 
 =head2 I<dbgout( $key, $value, $priority )>
