@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for ARC
-our $VERSION = '2.20200930.2'; # VERSION
+our $VERSION = '2.20201113.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
 use Mail::DKIM 1.20200824;
 use Mail::DKIM::ARC::Signer;
@@ -659,7 +659,7 @@ sub addheader_callback {
         my $arcseal = Mail::DKIM::ARC::Signer->new(
             Algorithm => $config->{arcseal_algorithm},
             Domain => $config->{arcseal_domain},
-            SrvId => $self->get_my_hostname(),
+            SrvId => $self->get_my_authserv_id(),
             Selector =>  $config->{arcseal_selector},
             Headers => $config->{arcseal_headers},
             # chain value is arc_result from previous seal validation
@@ -763,7 +763,7 @@ Mail::Milter::Authentication::Handler::ARC - Handler class for ARC
 
 =head1 VERSION
 
-version 2.20200930.2
+version 2.20201113.2
 
 =head1 DESCRIPTION
 
