@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler class for Removing headers
-our $VERSION = '2.20200930.2'; # VERSION
+our $VERSION = '2.20201113.2'; # VERSION
 use base 'Mail::Milter::Authentication::Handler';
 
 sub default_config {
@@ -46,6 +46,12 @@ sub is_hostname_mine {
     if ( $check_hostname =~ m/^(.*\.)?\Q${check_for}\E$/i ) {
         return 1;
     }
+
+    my $authserv_id = $self->get_my_authserv_id();
+    if ( fc( $check_hostname ) eq fc( $authserv_id ) ) {
+        return 1;
+    }
+
     return 0;
 }
 
@@ -173,7 +179,7 @@ Mail::Milter::Authentication::Handler::Sanitize - Handler class for Removing hea
 
 =head1 VERSION
 
-version 2.20200930.2
+version 2.20201113.2
 
 =head1 DESCRIPTION
 
